/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

public class TestNotRewriteLocalVariable {
    int a = 1;
    int b = 2;
    int c = 3;

    public TestNotRewriteFunctionParameter() {
        int b = this.b;
        int c = this.c;
        System.out.println(this.c + b + c + this.b);
    }

    public int myFun() {
        int a = this.a;
        return this.a + a + this.b + c;
    }
}
