/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.utils;

import org.apache.paimon.predicate.Predicate;

/**
 * Represents a filter (boolean-valued function) of one argument. This class is for avoiding name
 * conflicting to {@link Predicate}.
 */
@FunctionalInterface
public interface Filter<T> {

    Filter<?> ALWAYS_TRUE = t -> true;

    /**
     * Evaluates this predicate on the given argument.
     *
     * @param t the input argument
     * @return {@code true} if the input argument matches the predicate, otherwise {@code false}
     */
    boolean test(T t);

    default Filter<T> and(Filter<? super T> other) {
        if (other == null) {
            return this;
        }
        return t -> test(t) && other.test(t);
    }

    @SuppressWarnings({"unchecked", "rawtypes"})
    static <T> Filter<T> alwaysTrue() {
        return (Filter) ALWAYS_TRUE;
    }
}
